
Cryptographic function implementation
-------

**Description:**

Whenever cryptographic function is not implemented on the server side these cryptographic 
functions could easily be bypassed by an attacker 


**Solution:**

Verify that all cryptographic functions used to protect secrets from the application
user are implemented server side.

	